Enumeration
GpiodglibLineClock
since: 1.0
Members
GPIODGLIB_LINE_CLOCK_MONOTONIC-
Line uses the monotonic clock for edge event timestamps.
- Value:
1 - Nickname:
monotonic - Available since: 1.0
- Value:
GPIODGLIB_LINE_CLOCK_REALTIME-
Line uses the realtime clock for edge event timestamps.
- Value:
2 - Nickname:
realtime - Available since: 1.0
- Value:
GPIODGLIB_LINE_CLOCK_HTE-
Line uses the hardware timestamp engine for event timestamps.
- Value:
3 - Nickname:
hte - Available since: 1.0
- Value: